#
# spec file for package perl-Digest-SHA1
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Digest-SHA1
Name:           perl-Digest-SHA1
Version:        2.130.0
Release:        1.1
# 2.13 -> normalize -> 2.130.0
%define cpan_version 2.13
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl interface to the SHA-1 algorithm
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/G/GA/GAAS/%{cpan_name}-%{cpan_version}.tar.gz
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(Digest::SHA1) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The 'Digest::SHA1' module allows you to use the NIST SHA-1 message digest
algorithm from within Perl programs. The algorithm takes as input a message
of arbitrary length and produces as output a 160-bit "fingerprint" or
"message digest" of the input.

In 2005, security flaws were identified in SHA-1, namely that a possible
mathematical weakness might exist, indicating that a stronger hash function
would be desirable. The Digest::SHA module implements the stronger
algorithms in the SHA family.

The 'Digest::SHA1' module provide a procedural interface for simple use, as
well as an object oriented interface that can handle messages of arbitrary
length and which can read files directly.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes fip180-1.gif fip180-1.html README

%changelog
* Thu Jun 12 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Jul 16 2010 anicka@suse.cz
- update to 2.13
  * Fix memory leak in sha1_transform
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Fri Jun 26 2009 chris@computersalat.de
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o added header
  o fixed deps
* Mon May 25 2009 anicka@suse.cz
- update to 2.12
  * Get rid of the old CVS ids
  * Avoid "redefined" error for ULONG on Win64
  * Less optimizations on IRIX [RT#8999]
  * Clean up the 'git status' output
  * Mention that SHA-1 might be weak [RT#11880]
  * Ensure more stuff in the META.yml file [RT#40757]
  * Quiet warnings when compiled with -Wwrite-strings [RT#31915]
* Tue Jul 11 2006 anicka@suse.cz
- update to 2.11
- minor release
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Aug  6 2004 mjancar@suse.cz
- update to 2.10
* Thu Feb 26 2004 mjancar@suse.cz
- update to 2.07
* Tue Oct 21 2003 mjancar@suse.cz
- update to 2.06
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 24 2003 mjancar@suse.cz
- update to 2.04
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Mon Jun 16 2003 mjancar@suse.cz
- fix filelist
* Thu Jun  5 2003 mjancar@suse.cz
- don't package MANIFEST
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Tue Apr 29 2003 mjancar@suse.cz
- update to version 2.02
- used $RPM_OPT_FLAGS
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Tue Jan 15 2002 rvasice@suse.cz
- update to version 2.01
* Tue Aug 14 2001 rvasice@suse.cz
- initial package release (version 2.00)
